echo on
%
%--------------------------------------------------------------------
% This script builds a continuous 5x5 multivariable fired heater 
% model similar to the one we used in the 1998 MPC Workshop
%
%   process inputs:
%
%   1. pass flow #1 setpoint 		(BPH)
%   2. pass flow #2 setpoint 		(BPH)
%   3. fuel gas flow setpoint 		(SCFH)
%
%   process disturbances:
%
%   1. pass #1 inlet temperature 	(DEGF)
%   2. pass #2 inlet temperature 	(DEGF)
%
%   process outputs:
%
%   1. combined outlet temperature 	(DEGF)
%   2. combined outlet flowrate		(BPH)
%   3. pass temp diff (1 - 2)		(DEGF)
%   4. pass 1 tubeskin temperature	(DEGF)
%   5. pass 2 tubeskin temperature	(DEGF)
%
%--------------------------------------------------------------------
%

% pause % Press any key to continue ...

%
%	Build the transfer functions for outlet temp
%
   num11 = [-0.8];
   den11 = conv([1 1],[2 1]);
%
   num12 = [-0.8];
   den12 = conv([1 1],[2 1]);
%
   num13 = [6.0];
   den13 = conv([1 1],[3 1]);
%
   num14 = [0.35];
   den14 = conv([1 1],[2 1]);
%
   num15 = [0.35];
   den15 = conv([1 1],[2 1]);

% pause % Press any key to continue ...

%
%	Build the transfer functions for outlet flow
%
   num21 = [1.0];
   den21 = [2 1];
%
   num22 = [1.0];
   den22 = [2 1];

% pause % Press any key to continue ...

%
%	Build the transfer functions for delta T
%
   num31 = [-1.0];
   den31 = conv([10 1],[15 1]);
%
   num32 = [1.0];
   den32 = conv([10 1],[15 1]);
%
   num34 = [0.4];
   den34 = conv([1 1],[2 1]);
%
   num35 = [-0.4];
   den35 = conv([1 1],[2 1]);

% pause % Press any key to continue ...

%
%       Build the transfer function for TS1 
% 
   num41 = [-1.2];
   den41 = [1 1];
%
   num43 = [10];
   den43 = conv([1 1],[2 1]);
%
   num44 = [0.8];
   den44 = [1 1];

% pause % Press any key to continue ...

%
%       Build the transfer function for TS2
%
   num52 = [-1.2];
   den52 = [1 1];
%
   num53 = [10];
   den53 = conv([1 1],[2 1]);
%
   num55 = [0.8];
   den55 = [1 1];

% pause % Press any key to continue ...

%
%	Construct individual continuous state space systems for each
%	transfer function.
%
   [a11,b11,c11,d11] = tf2ss(num11,den11);
   [a12,b12,c12,d12] = tf2ss(num12,den12);
   [a13,b13,c13,d13] = tf2ss(num13,den13);
   [a14,b14,c14,d14] = tf2ss(num14,den14);
   [a15,b15,c15,d15] = tf2ss(num15,den15);
%
   [a21,b21,c21,d21] = tf2ss(num21,den21);
   [a22,b22,c22,d22] = tf2ss(num22,den22);
%
   [a31,b31,c31,d31] = tf2ss(num31,den31);
   [a32,b32,c32,d32] = tf2ss(num32,den32);
   [a34,b34,c34,d34] = tf2ss(num34,den34);
   [a35,b35,c35,d35] = tf2ss(num35,den35);
%  
   [a41,b41,c41,d41] = tf2ss(num41,den41);
   [a43,b43,c43,d43] = tf2ss(num43,den43);
   [a44,b44,c44,d44] = tf2ss(num44,den44);
%
   [a52,b52,c52,d52] = tf2ss(num52,den52);
   [a53,b53,c53,d53] = tf2ss(num53,den53);
   [a55,b55,c55,d55] = tf2ss(num55,den55);

% pause % Press any key to continue ...

%
%	Set the deadtimes and sample time of 1 minute.
%
   Ts = 1;
   
% pause % Press any key to continue ...

%
%	Construct the system A matrix
%
   AD = [];
   aZ =  0;
%
   AD = dgapp(AD,a11);
   AD = dgapp(AD,a12);
   AD = dgapp(AD,a13);
   AD = dgapp(AD,a14);
   AD = dgapp(AD,a15);
%
   AD = dgapp(AD,a21);
   AD = dgapp(AD,a22);
   AD = dgapp(AD,aZ);
   AD = dgapp(AD,aZ);
   AD = dgapp(AD,aZ);
%
   AD = dgapp(AD,a31);
   AD = dgapp(AD,a32);
   AD = dgapp(AD,aZ);
   AD = dgapp(AD,a34);
   AD = dgapp(AD,a35);
%  
   AD = dgapp(AD,a41);
   AD = dgapp(AD,aZ);
   AD = dgapp(AD,a43);
   AD = dgapp(AD,a44);
   AD = dgapp(AD,aZ);
%
   AD = dgapp(AD,aZ);
   AD = dgapp(AD,a52);
   AD = dgapp(AD,a53);
   AD = dgapp(AD,aZ);
   AD = dgapp(AD,a55);

% pause % Press any key to continue ...

%
%	Construct the system B matrix
%
   BD = [];
   bZ =  0;
%
   BD = dgapp(BD,b11);
   BD = dgapp(BD,b12);
   BD = dgapp(BD,b13);
   BD = dgapp(BD,b14);
   BD = dgapp(BD,b15);
%
   BD = dgapp(BD,b21);
   BD = dgapp(BD,b22);
   BD = dgapp(BD,bZ);
   BD = dgapp(BD,bZ);
   BD = dgapp(BD,bZ);
%
   BD = dgapp(BD,b31);
   BD = dgapp(BD,b32);
   BD = dgapp(BD,bZ);
   BD = dgapp(BD,b34);
   BD = dgapp(BD,b35);
%
   BD = dgapp(BD,b41);
   BD = dgapp(BD,bZ);
   BD = dgapp(BD,b43);
   BD = dgapp(BD,b44);
   BD = dgapp(BD,bZ);
%
   BD = dgapp(BD,bZ);
   BD = dgapp(BD,b52);
   BD = dgapp(BD,b53);
   BD = dgapp(BD,bZ);
   BD = dgapp(BD,b55);
%
   IM  = [];
   Inu = eye(5);
   for i = 1:5
      IM = [IM ; Inu];
   end
   BD = BD*IM;

% pause % Press any key to continue ...

%
%	Construct the system C matrix
%
   cZ  = 0;
   CD1 = [c11 c12 c13 c14 c15];
   CD2 = [c21 c22 cZ  cZ  cZ ];
   CD3 = [c31 c32 cZ  c34 c35];
   CD4 = [c41 cZ  c43 c44 cZ ];
   CD5 = [cZ  c52 c53 cZ  c55];
   CD  = [ ];
   CD  = dgapp(CD,CD1); 
   CD  = dgapp(CD,CD2); 
   CD  = dgapp(CD,CD3);
   CD  = dgapp(CD,CD4);
   CD  = dgapp(CD,CD5); 

% pause % Press any key to continue ...

%
%	Construct the system D matrix
%
   dZ  = 0;
   DD1 = [d11 d12 d13 d14 d15];
   DD2 = [d21 d22 dZ  dZ  dZ ];
   DD3 = [d31 d32 dZ  d34 d35];
   DD4 = [d41 dZ  d43 d44 dZ ];
   DD5 = [dZ  d52 d53 dZ  d55];
   DD  = [DD1;DD2;DD3;DD4;DD5];

% pause % Press any key to continue ...

%
%	Get a minimal realization
%
   [A,B,C,D] = minreal(AD,BD,CD,DD);

% pause % Press any key to continue ...

%
%   Build heater state space model
%
   heater = ss(A,B,C,D);
   heater.OutputName = {'TO.PV','FO.PV','DT.PV','TS1.PV','TS2.PV'};
   heater.OutputUnit = {'DEGF','BPH','DEGF','DEGF','DEGF'};
   heater.InputName = {'FC1.SP','FC2.SP','FG.SP','TI1.PV','TI2.PV'};
   heater.InputUnit = {'BPH','BPH','MSCFH','DEGF','DEGF'};
   heater.TimeUnit = 'minutes';
   
%
%	Plot the system step response
%
   step(heater,100)
   grid

%
%   Save the heater model matrices
%

save('HeaterModelCont','A','B','C','D')

echo off
%
%	Exit
%
